@@ -2,6 +2,7 @@
 """ parse_ansible_json.py
 Parses Ansible JSON output and turns it into pretty markdown output.
 """
+import os
 from textwrap import dedent
 from typing import List
 
@@ -25,6 +26,7 @@ class ParseAnsibleJson(BuildToolsTemplate):
         super().__init__(cli_path, cli_descriptions, summary)
 
     def _save_fragments_to_files(self, fragments, dst_file_base):
+        dst_file_base = os.path.splitext(dst_file_base)[0]
         # Calculate index and 'max_index_str_size' for use in formatting the output filename
         max_index_str_size = len(str(len(fragments) + 1))
         index = 0
@@ -47,7 +49,7 @@ class ParseAnsibleJson(BuildToolsTemplate):
                 fragments = split_markdown(str(markdown), args.fragment_size)
                 self._save_fragments_to_files(fragments, args.dst)
             else:
-                with open(f'{args.dst}.md', 'w') as dst_file:
+                with open(args.dst, 'w') as dst_file:
                     dst_file.write(str(markdown))
         except FileNotFoundError:
             print(f"[ERROR] No such file: {args.src}\n")
