@@ -8,6 +8,7 @@ from mistletoe import Document
 from buildtools.util.ansible_json_parser import AnsibleJSONParser
 from buildtools.util.fragment_markdown_parser import FragmentRenderer
 from buildtools.util.markdown_comment_builder import BitbucketMarkdownComment
+from buildtools.util.playbook_parser import PlaybookLimit
 
 
 class BuildToolsValueError(BaseException):
@@ -51,6 +52,12 @@ def parse_ansible_json(json):
     return parser.parse(json)
 
 
+def infer_playbook_limit(source_path, hosts_path):
+    pl = PlaybookLimit(hosts_path=hosts_path)
+    with open(source_path) as f:
+        return pl.infer_playbook_limit(f.readlines())
+
+
 def split_markdown(input: str, fragment_size: int, min_fragment_size: int = None) -> List[str]:
     """Split the provided input string into "Markdown fragments". There are many cases where fragmentation could break
     the Markdown syntax.
