@@ -1,4 +1,5 @@
 from enum import Enum
+from textwrap import dedent
 
 import buildtools.util as util
 from buildtools.util.teams_card_builder import TeamsCardTemplate
@@ -13,7 +14,7 @@ class TeamsMessageTypes(Enum):
 class PullRequestCard(TeamsCardTemplate):
     def __init__(self, args):
         required_arguments = {'bitbucket_url', 'project', 'repo_slug', 'pull_request_id', 'pull_request_author', 'pull_request_title', 'pull_request_dest'}
-        optional_arguments = {'pull_request_description', 'playbook_limit', 'jenkins_build_url'}
+        optional_arguments = {'pull_request_description', 'playbook_limit', 'jenkins_build_url', 'build_status'}
         super().__init__(required_arguments, optional_arguments, args)
 
     def build(self, args):
@@ -26,10 +27,15 @@ class PullRequestCard(TeamsCardTemplate):
         # Section with pull request facts
         pr_facts = self.add_section()
         pr_facts.add_fact("Requested by", args.pull_request_author)
-        pr_facts.add_fact("Repository", args.repo_slug)
         if util.hasattr_nonempty_str(args, 'playbook_limit') : # playbook_limit is optional
             pretty_playbook_limit = args.playbook_limit.replace(',', ' ︙ ')
             pr_facts.add_fact("Playbook limit", pretty_playbook_limit)
+        if util.hasattr_nonempty_str(args, 'build_status'):  # build_status is optional
+            if args.build_status == 'FAILURE':  # Add emphasis if this is a failure.
+                pr_facts.add_fact("Build Status", f'***{args.build_status}***')
+            else:
+                pr_facts.add_fact("Build Status", args.build_status)
+
         pr_facts.add_fact("Destination branch", args.pull_request_dest)
             
         # Section with the pull request description (optional)
@@ -37,10 +43,11 @@ class PullRequestCard(TeamsCardTemplate):
             self.add_section().add_text(args.pull_request_description)
 
         # Actions that you should take now (buttons at the bottom)!
-        self.add_button(f"Review Pull Request {args.pull_request_id} Now!", pull_request_url)
-        self.add_button(f"Review diff", pull_request_diff_url)
+        self.add_button(f"Review PR #{args.pull_request_id}", pull_request_url)
+        self.add_button(f"See proposed changes!", pull_request_diff_url)
         if util.hasattr_nonempty_str(args, 'jenkins_build_url'):
-            self.add_button(f"Jenkins build", args.jenkins_build_url) 
+            self.add_button(f"Jenkins build", args.jenkins_build_url)
+            # TODO: Add a 'Rebuild in Jenkins' button also (which will be possible only if ditch our 'buildWithParameters' pipelines so we can use the '/build' endpoint )
 
 
 class PullRequestUpdateCard(TeamsCardTemplate):
@@ -125,23 +132,49 @@ class TeamsCardFactory:
 
     @staticmethod
     def _add_messages(args, card):
+        """Add 'messages' that are found in `args` to `card`.
+
+        :param args: The args to be scanned for `message` or `file`.
+        :param card: The card that will be updated with any 'messages' found in `args`.
+        :return: The card.
+        """
         if util.hasattr_nonempty_str(args, 'message') and len(args.message) > 0:
             TeamsCardFactory._add_message(args, card, args.message)
         if util.hasattr_nonempty_str(args, 'file') and len(args.file) > 0:
             TeamsCardFactory._add_message(args, card, util.readfile(args.file))
         return card
-    
+
     @staticmethod
     def _add_message(args, card, message):
-        mc = MarkdownComment()            
+        """Add the message to the card. Formatting details may be specified in args.
+
+        :param args: The args to be scanned for formatting details, e.g. `max_size`, and `code_markdown`
+        :param card: The card that will be updated with the `message`.
+        :param message: The message to be added to the `card`.
+        :return: The card.
+        """
+        mc = MarkdownComment()
+        trimmed = False
+        if args.max_size:
+            fragments = util.split_markdown(message, args.max_size//2)
+            if len(fragments) >= 2:
+                trimmed = True
+                message = ''
+                i = -1
+                while len(message) < args.max_size:
+                    message += fragments[i]
+                    i += -1
         if hasattr(args, 'code_markdown') and args.code_markdown:
             mc.add_code_markdown(message)
         else:
             mc.add_message(message)
-        if args.tail:
-            mc.trim_comment(args.tail)
-        card.add_section(str(mc))
 
+        rendered = ''
+        if trimmed:
+            rendered += '> *Below message is trimmed. **See Pull Request** for full message... (or Jenkins Build)*\n\n'
+        rendered += str(mc)
+
+        card.add_section(rendered)
 
     @staticmethod
     def _build(args):
